==> flutter_custom_form_component-0.0.8.tar.gz: lib/widget/field/date/422/yyyymmdd.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_custom_form_component/widget/field/date/422/formatter.dart';
import 'package:flutter_custom_form_component/widget/field/date/mixin.dart';
import 'package:flutter_custom_form_component/widget/field/mixin.dart';

/// Text field supports YYYYMMDD date format and validation.
/// For another date format can refer to DdMmYyyyFieldWidget, MmDdYyyyFieldWidget or YyyyDdMmFieldWidget.
class YyyyMmDdFieldWidget extends StatefulWidget {
  late final String _hint;
  late final int? _initialYear, _initialMonth, _initialDay;
  late final bool _isValid;
  late final Function(int? year, int? month, int? day)? _onChanged;
  late final String _separator;

  YyyyMmDdFieldWidget(
      {String hint = 'yyyy - mm - dd',
      int? initialYear,
      int? initialMonth,
      int? initialDay,
      bool isValid = true,
      Function(int? year, int? month, int? day)? onChanged,
      String separator = ' - ',
      Key? key})
      : super(key: key) {
    _hint = hint;
    _initialYear = initialYear;
    _initialMonth = initialMonth;
    _initialDay = initialDay;
    _isValid = isValid;
    _onChanged = onChanged;
    _separator = separator;
  }

  @override
  State<StatefulWidget> createState() => _State();
}

/// State of YyyyMmDdFieldWidget.
class _State extends State<YyyyMmDdFieldWidget>
    with DateFieldStateMixin, FieldWidgetMixin {
  @override
  Widget build(final BuildContext context) =>
      buildMixin(context, hint: widget._hint);

  @override
  void dispose() {
    disposeMixin();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    String? initialYear, initialMonth, initialDay, initialDate;
    if (widget._initialYear != null) {
      initialYear = formatter.completeDigits(widget._initialYear!, digits: 4);
    }
    if (widget._initialMonth != null) {
      initialMonth = formatter.completeDigits(widget._initialMonth!, digits: 2);
    }
    if (widget._initialDay != null) {
      initialDay = formatter.completeDigits(widget._initialDay!, digits: 2);
    }
    if (initialYear != null && initialMonth != null && initialDay != null) {
      initialDate = formatter.format('$initialYear$initialMonth$initialDay');
    }
    initStateMixin(
        initialDate: initialDate,
        initialValid: widget._isValid,
        separator: widget._separator);
  }

  /// Obtaining the day, month and year. Then calling external validation (widget._onChanged).
  @override
  void onChanged() {
    final List<String> strings = split(separator: widget._separator);
    year = int.tryParse(strings.isNotEmpty ? strings[0] : '');
    month = int.tryParse(strings.length > 1 ? strings[1] : '');
    day = int.tryParse(strings.length > 2 ? strings[2] : '');
    widget._onChanged?.call(year, month, day);
  }

  /// Refreshing the UI by calling setState().
  @override
  void refresh() => setState(() {});

  @override
  Date422Formatter get formatter => Date422Formatter(widget._separator);
}

==> flutter_custom_form_component-0.0.12.tar.gz: lib/widget/field/date/422/yyyymmdd.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_custom_form_component/widget/field/date/422/formatter.dart';
import 'package:flutter_custom_form_component/widget/field/date/mixin.dart';
import 'package:flutter_custom_form_component/widget/field/mixin.dart';
import 'package:flutter_custom_form_component/widget/field/widget.dart';

/// Text field supports YYYYMMDD date format and validation.
/// For another date format can refer to DdMmYyyyFieldWidget, MmDdYyyyFieldWidget or YyyyDdMmFieldWidget.
class YyyyMmDdFieldWidget extends FieldWidget {
  late final int? _initialYear, _initialMonth, _initialDay;
  late final bool _valid;
  late final Function(int? year, int? month, int? day)? _onChanged;
  late final String _separator;

  YyyyMmDdFieldWidget(
      {final TextInputAction action = TextInputAction.next,
      final BoxDecoration? decoration,
      final bool enabled = true,
      final BoxDecoration? errorDecoration,
      final TextStyle? errorStyle,
      final String hint = 'yyyy - mm - dd',
      final int? initialYear,
      final int? initialMonth,
      final int? initialDay,
      final Key? key,
      final Function(int? year, int? month, int? day)? onChanged,
      final String separator = ' - ',
      final TextStyle? style,
      final bool valid = true})
      : super(
            action: action,
            decoration: decoration,
            enabled: enabled,
            errorDecoration: errorDecoration,
            errorStyle: errorStyle,
            hint: hint,
            key: key,
            style: style) {
    _initialYear = initialYear;
    _initialMonth = initialMonth;
    _initialDay = initialDay;
    _onChanged = onChanged;
    _separator = separator;
    _valid = valid;
  }

  @override
  State<StatefulWidget> createState() => _State();
}

/// State of YyyyMmDdFieldWidget.
class _State extends State<YyyyMmDdFieldWidget>
    with DateFieldStateMixin, FieldMixin {
  @override
  Widget build(final BuildContext context) => buildMixin(context,
      action: widget.action,
      decoration: widget.decoration,
      errorDecoration: widget.errorDecoration,
      errorStyle: widget.errorStyle,
      hint: widget.hint,
      style: widget.style);

  @override
  void dispose() {
    disposeMixin();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    String? initialYear, initialMonth, initialDay, initialDate;
    if (widget._initialYear != null) {
      initialYear = formatter.completeDigits(widget._initialYear!, digits: 4);
    }
    if (widget._initialMonth != null) {
      initialMonth = formatter.completeDigits(widget._initialMonth!, digits: 2);
    }
    if (widget._initialDay != null) {
      initialDay = formatter.completeDigits(widget._initialDay!, digits: 2);
    }
    if (initialYear != null && initialMonth != null && initialDay != null) {
      initialDate = formatter.format('$initialYear$initialMonth$initialDay');
    }
    initStateMixin(
        initialDate: initialDate,
        initialValid: widget._valid,
        separator: widget._separator);
  }

  /// Obtaining the day, month and year. Then calling external validation (widget._onChanged).
  @override
  void onChanged() {
    final List<String> strings = split(separator: widget._separator);
    year = int.tryParse(strings.isNotEmpty ? strings[0] : '');
    month = int.tryParse(strings.length > 1 ? strings[1] : '');
    day = int.tryParse(strings.length > 2 ? strings[2] : '');
    widget._onChanged?.call(year, month, day);
  }

  /// Refreshing the UI by calling setState().
  @override
  void refresh() => setState(() {});

  @override
  Date422Formatter get formatter => Date422Formatter(widget._separator);
}
